"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DEFAULT_ACCEPT = void 0;
const config_firebase_dam_1 = __importDefault(require("config:firebase-dam?"));
const icons_1 = require("@sanity/icons");
const getFirebaseClient_1 = __importDefault(require("./getFirebaseClient"));
exports.DEFAULT_ACCEPT = [
    'video/*',
    'audio/*',
];
const { defaultAccept, toolTitle } = config_firebase_dam_1.default !== null && config_firebase_dam_1.default !== void 0 ? config_firebase_dam_1.default : {};
const config = {
    id: 'firebase-dam',
    customDataFieldName: 'firebase',
    defaultAccept: defaultAccept !== null && defaultAccept !== void 0 ? defaultAccept : exports.DEFAULT_ACCEPT,
    toolTitle: toolTitle !== null && toolTitle !== void 0 ? toolTitle : "Videos & Audio (Firebase)",
    supportsProgress: true,
    credentialsFields: [
        {
            name: 'apiKey',
            title: 'API Key',
            icon: icons_1.LockIcon,
            type: 'string',
            validation: Rule => Rule.required(),
        },
        {
            name: 'storageBucket',
            title: 'Storage Bucket',
            icon: icons_1.LinkIcon,
            type: 'string',
            validation: Rule => Rule.required(),
        },
    ],
    deleteFile: ({ storedFile, credentials }) => __awaiter(void 0, void 0, void 0, function* () {
        var _a;
        try {
            const firebaseClient = (0, getFirebaseClient_1.default)(credentials);
            yield firebaseClient.storage().ref((_a = storedFile.firebase) === null || _a === void 0 ? void 0 : _a.fullPath).delete();
            return true;
        }
        catch (error) {
            if ((error === null || error === void 0 ? void 0 : error.code) === 'storage/object-not-found') {
                // If file not found in Firebase, we're good!
                return true;
            }
            return 'Error';
        }
    }),
    uploadFile: ({ credentials, onError, onSuccess, file, fileName, updateProgress, }) => {
        const firebaseClient = (0, getFirebaseClient_1.default)(credentials);
        const ref = firebaseClient.storage().ref(fileName);
        const uploadTask = ref.put(file, {
            customMetadata: {
                uploadedFrom: 'sanity-plugin-firebase-dam',
            },
        });
        uploadTask.on('state_changed', (snapshot) => {
            const progress = Math.ceil((snapshot.bytesTransferred / snapshot.totalBytes) * 100);
            updateProgress(progress);
        }, (error) => {
            onError(error);
        }, () => __awaiter(void 0, void 0, void 0, function* () {
            const downloadURL = yield uploadTask.snapshot.ref.getDownloadURL();
            const metadata = yield uploadTask.snapshot.ref.getMetadata();
            onSuccess({
                fileURL: downloadURL,
                firebase: {
                    bucket: metadata.bucket,
                    contentDisposition: metadata.contentDisposition,
                    contentEncoding: metadata.contentEncoding,
                    fullPath: metadata.fullPath,
                    md5Hash: metadata.md5Hash,
                    generation: metadata.generation,
                    metageneration: metadata.metageneration,
                    type: metadata.type,
                },
            });
        }));
        return () => {
            try {
                uploadTask.cancel();
            }
            catch (error) { }
        };
    },
};
exports.default = config;
